@@ -25,6 +25,7 @@
 #include "monthitem.h"
 #include "monthview.h"
 #include "prefs.h"
+#include "helper_p.h"
 
 #include <CalendarSupport/Utils>
 
@@ -42,15 +43,15 @@ MonthScene::MonthScene(MonthView *parent)
     : QGraphicsScene(parent),
       mMonthView(parent),
       mInitialized(false),
-      mClickedItem(Q_NULLPTR),
-      mActionItem(Q_NULLPTR),
+      mClickedItem(nullptr),
+      mActionItem(nullptr),
       mActionInitiated(false),
-      mSelectedItem(Q_NULLPTR),
-      mStartCell(Q_NULLPTR),
-      mPreviousCell(Q_NULLPTR),
+      mSelectedItem(nullptr),
+      mStartCell(nullptr),
+      mPreviousCell(nullptr),
       mActionType(None),
       mStartHeight(0),
-      mCurrentIndicator(Q_NULLPTR)
+      mCurrentIndicator(nullptr)
 {
     mBirthdayPixmap  = QIcon::fromTheme(QStringLiteral("view-calendar-birthday")).pixmap(16, 16);
     mAnniversaryPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-wedding-anniversary")).pixmap(16, 16);
@@ -123,12 +124,12 @@ MonthCell *MonthScene::firstCellForMonthItem(MonthItem *manager)
         }
     }
 
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void MonthScene::updateGeometry()
 {
-    foreach (MonthItem *manager, mManagerList) {
+    for (MonthItem *manager : qAsConst(mManagerList)) {
         manager->updateGeometry();
     }
 }
@@ -369,9 +370,9 @@ void MonthScene::resetAll()
     qDeleteAll(mManagerList);
     mManagerList.clear();
 
-    mSelectedItem = Q_NULLPTR;
-    mActionItem = Q_NULLPTR;
-    mClickedItem = Q_NULLPTR;
+    mSelectedItem = nullptr;
+    mActionItem = nullptr;
+    mClickedItem = nullptr;
 }
 
 Akonadi::IncidenceChanger *MonthScene::incidenceChanger() const
@@ -458,7 +459,7 @@ void MonthScene::scrollCellsDown()
     int newHeight = startHeight() + 1;
     setStartHeight(newHeight);
 
-    foreach (MonthItem *manager, mManagerList) {
+    for (MonthItem *manager : qAsConst(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -470,7 +471,7 @@ void MonthScene::scrollCellsUp()
     int newHeight = startHeight() - 1;
     setStartHeight(newHeight);
 
-    foreach (MonthItem *manager, mManagerList) {
+    for (MonthItem *manager : qAsConst(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -573,8 +574,8 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
     QPointF pos = mouseEvent->scenePos();
 
-    mClickedItem = Q_NULLPTR;
-    mCurrentIndicator = Q_NULLPTR;
+    mClickedItem = nullptr;
+    mCurrentIndicator = nullptr;
 
     MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos));
     if (iItem) {
@@ -616,7 +617,7 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
         repeatTimer.start(AUTO_REPEAT_DELAY, this);
     } else {
         // unselect items when clicking somewhere else
-        selectItem(Q_NULLPTR);
+        selectItem(nullptr);
 
         MonthCell *cell = getCellFromPos(pos);
         if (cell) {
@@ -637,7 +638,7 @@ void MonthScene::timerEvent(QTimerEvent *e)
             clickOnScrollIndicator(mCurrentIndicator);
             repeatTimer.start(AUTO_REPEAT_DELAY, this);
         } else {
-            mCurrentIndicator = Q_NULLPTR;
+            mCurrentIndicator = nullptr;
             repeatTimer.stop();
         }
     }
@@ -667,7 +668,7 @@ void MonthScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
     static_cast<MonthGraphicsView *>(views().at(0))->setActionCursor(None);
 
     repeatTimer.stop();
-    mCurrentIndicator = Q_NULLPTR;
+    mCurrentIndicator = nullptr;
 
     if (mActionItem) {
         MonthCell *currentCell = getCellFromPos(pos);
@@ -682,9 +683,9 @@ void MonthScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
             }
         }
 
-        mActionItem = Q_NULLPTR;
+        mActionItem = nullptr;
         mActionType = None;
-        mStartCell = Q_NULLPTR;
+        mStartCell = nullptr;
 
         mouseEvent->accept();
     }
@@ -704,7 +705,7 @@ MonthCell *MonthScene::getCellFromPos(const QPointF &pos)
     int y = sceneYToMonthGridY(static_cast<int>(pos.y()));
     int x = sceneXToMonthGridX(static_cast<int>(pos.x()));
     if (!isInMonthGrid(x, y)) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     int id = (int)(y / rowHeight()) * 7 + (int)(x / columnWidth());
 
@@ -726,7 +727,7 @@ void MonthScene::selectItem(MonthItem *item)
     IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(item);
 
     if (!tmp) {
-        mSelectedItem = Q_NULLPTR;
+        mSelectedItem = nullptr;
         Q_EMIT incidenceSelected(Akonadi::Item(), QDate());
         return;
     }
@@ -744,7 +745,7 @@ void MonthScene::selectItem(MonthItem *item)
 
 void MonthScene::removeIncidence(const QString &uid)
 {
-    foreach (MonthItem *manager, mManagerList) {
+    for (MonthItem *manager : qAsConst(mManagerList)) {
         IncidenceMonthItem *imi = qobject_cast<IncidenceMonthItem *>(manager);
         if (!imi) {
             continue;
